@@ -1,15 +1,17 @@
-;;; evil-keypad.el --- Modal command dispatch that speaks native Emacs keybindings -*- lexical-binding: t; -*-
+;;; evil-keypad.el --- Modal command dispatch for evil-mode -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2025 Achyudh Ram <mail@achyudh.me>
 ;; Author: Achyudh Ram <mail@achyudh.me>
 ;; Maintainer: Achyudh Ram <mail@achyudh.me>
 ;; Created: 2025-05-03
-;; Package-Requires: ((emacs "29.1") (which-key "3.0"))
-;; Package-Version: 0.1.5
-;; Package-Revision: faa3ec151caa
-;; Keywords: evil, keypad, modal, command, dispatch
+;; Package-Requires: ((emacs "30.1") (evil "1.0.0"))
+;; Package-Version: 20250731.552
+;; Package-Revision: f384b8818015
+;; Keywords: convenience, emulation
 ;; URL: https://github.com/achyudh/evil-keypad
 
+;; SPDX-License-Identifier: GPL-3.0-or-later
+
 ;; This file is not part of GNU Emacs.
 
 ;; This program is free software; you can redistribute it and/or
@@ -29,14 +31,14 @@
 
 ;;; Commentary:
 ;; Provides `evil-keypad-start', a command to activate a transient
-;; keypad mode inspired by Meow Keypad. Allows entering complex Emacs
+;; keypad mode inspired by Meow Keypad.  Allows entering complex Emacs
 ;; key sequences using a series of single key presses without holding
 ;; down modifier keys.
 ;;
 ;; After triggering the keypad, type a sequence representing modifiers
 ;; and keys (e.g., 'x f' for C-x C-f, 'm x' for M-x, 'a s' for C-c a
-;; s). The keypad translates and executes the corresponding Emacs
-;; command, then exits. Numeric prefix arguments (e.g. C-u 4, M-5)
+;; s).  The keypad translates and executes the corresponding Emacs
+;; command, then exits.  Numeric prefix arguments (e.g. C-u 4, M-5)
 ;; can be initiated using dedicated keypad keys before command keys.
 ;;
 ;; Which-key integration is provided if `which-key-mode` is active,
@@ -55,22 +57,21 @@
 (defvar evil-keypad--keys nil
   "Internal list representing the keys sequence during keypad invocation.
 Stores (MODIFIER . KEY-STRING) cons cells, ordered most recent first.
-MODIFIER is a symbol like 'literal, 'control, 'meta, 'control-meta.
+MODIFIER is a symbol like \\='literal, \\='control, \\='meta, \\='control-meta.
 KEY-STRING is the result of `single-key-description'.")
 
 (defvar evil-keypad--pending-modifier nil
-  "Stores the pending modifier symbol ('meta, 'control-meta, 'literal) triggered
-by the previous key press, to be applied to the next key.")
+  "Stores the pending modifier symbol to be applied to the next key.")
 
 (defvar evil-keypad--session-initial-prefix-arg nil
   "Prefix argument active in Emacs before this keypad session started.")
 
 (defvar evil-keypad--session-active-prefix-arg nil
   "Prefix argument built or active during the current keypad session.
-Can be nil, an integer, a list like '(4) for C-u, or '- for M-- (raw minus).")
+Can be nil, an integer, a list like \\='(4) for C-u, or \\='- for M-- (raw minus).")
 
 (defvar evil-keypad--control-inducing-sequence-p nil
-  "Non-nil if the current keypad sequence context implies subsequent keys default to Control.
+  "Non-nil if the current keypad sequence context implies keys default to Control.
 Set based on the first command key of the sequence (e.g. x, c, m, g).")
 
 (defvar evil-keypad--display-timer nil
@@ -91,44 +92,45 @@ Set based on the first command key of the sequence (e.g. x, c, m, g).")
 
 ;;;###autoload
 (defcustom evil-keypad-activation-trigger (kbd "SPC")
-  "Key to activate `evil-keypad-start` globally when `evil-keypad-global-mode` is on.
-Works in Evil states defined by `evil-keypad-activation-states`."
+  "Key to activate `evil-keypad-start` globally.
+Works when `evil-keypad-global-mode` is non-nil and Evil state is one of
+`evil-keypad-activation-states`."
   :type 'string :group 'evil-keypad)
 
 ;;;###autoload
-(defcustom evil-keypad-activation-states '(normal visual emacs)
-  "A list of Evil states where the `evil-keypad-activation-trigger` should be active."
+(defcustom evil-keypad-activation-states '(normal visual motion emacs)
+  "Evil states where the `evil-keypad-activation-trigger` should be active."
   :type '(repeat symbol) :group 'evil-keypad)
 
 ;;;###autoload
 (defcustom evil-keypad-M-trigger ?m
-  "Character entered in keypad to trigger the Meta modifier for the next key."
+  "Character to trigger Meta modifier for the next key in keypad."
   :type 'character :group 'evil-keypad)
 
 ;;;###autoload
 (defcustom evil-keypad-C-M-trigger ?g
-  "Character entered in keypad to trigger the Control-Meta modifier for the next key."
+  "Character to trigger Control-Meta modifier for the next key in keypad."
   :type 'character :group 'evil-keypad)
 
 ;;;###autoload
 (defcustom evil-keypad-literal-trigger ?\s ; Space character
-  "Character entered in keypad (after first key) to trigger literal interpretation
-for the next key."
+  "Character to trigger literal interpretation for the next key in keypad.
+Used after first key is entered."
   :type 'character :group 'evil-keypad)
 
 ;;;###autoload
 (defcustom evil-keypad-C-x-trigger ?x
-  "Character entered as the first key in keypad to represent the C-x prefix."
+  "Character used as first key in keypad to represent the C-x prefix."
   :type 'character :group 'evil-keypad)
 
 ;;;###autoload
 (defcustom evil-keypad-C-c-trigger ?c
-  "Character entered as the first key in keypad to represent the C-c prefix."
+  "Character used as first key in keypad to represent the C-c prefix."
   :type 'character :group 'evil-keypad)
 
 ;;;###autoload
 (defcustom evil-keypad-C-h-trigger ?h
-  "Character used as the first key in keypad to represent the C-h prefix."
+  "Character used as first key in keypad to represent the C-h prefix."
   :type 'character :group 'evil-keypad)
 
 ;;;###autoload
@@ -141,6 +143,19 @@ for the next key."
   "Keypad key to emulate `negative-argument` (M-- or C-u -)."
   :type 'character :group 'evil-keypad)
 
+;;;###autoload
+(defcustom evil-keypad-quit-key (kbd "C-g")
+  "Key to quit the keypad input state."
+  :type 'string :group 'evil-keypad)
+
+;;;###autoload
+(defcustom evil-keypad-prefix-help-command nil
+  "Command to run when `help-char` is pressed after a prefix.
+This command is used only when there is no actual binding for `help-char`
+after that prefix. The function is called with one argument: the keymap for
+the current prefix."
+  :type '(function :tag "Help function")
+  :group 'evil-keypad)
 
 ;;----------------------------------------
 ;; Global Trigger Activation
@@ -149,6 +164,11 @@ for the next key."
 (defvar evil-keypad-global-activation-map (make-sparse-keymap)
   "Keymap for `evil-keypad-global-mode`.")
 
+(defun evil-keypad-global-mode--maybe-setup-evil-integration ()
+  "Setup evil integration if evil is available."
+  (when (featurep 'evil)
+    (evil-keypad--setup-global-activation-bindings)))
+
 (defun evil-keypad--setup-global-activation-bindings ()
   "Set up bindings in `evil-keypad-global-activation-map` for target states.
 Assumes `evil.el` is loaded."
@@ -175,20 +195,15 @@ in Evil states defined by `evil-keypad-activation-states`."
   :global t
   :lighter nil ; Example: " EKAct"
   :keymap evil-keypad-global-activation-map
+  :group 'evil-keypad
   (if evil-keypad-global-mode
       (if (featurep 'evil)
           (evil-keypad--setup-global-activation-bindings)
-        (with-eval-after-load 'evil
-          (evil-keypad--setup-global-activation-bindings)))
-    (when (featurep 'evil) ; Only clear if evil functions are available
+        (add-hook 'evil-mode-hook #'evil-keypad-global-mode--maybe-setup-evil-integration))
+    (remove-hook 'evil-mode-hook #'evil-keypad-global-mode--maybe-setup-evil-integration)
+    (when (featurep 'evil)
       (evil-keypad--clear-global-activation-bindings))))
 
-;; Fallback setup if evil loads after this mode was already enabled (e.g., via customize)
-(with-eval-after-load 'evil
-  (when (and (boundp 'evil-keypad-global-mode)
-             evil-keypad-global-mode)
-    (evil-keypad--setup-global-activation-bindings)))
-
 ;;----------------------------------------
 ;; Formatting Functions
 ;;----------------------------------------
@@ -246,7 +261,7 @@ in Evil states defined by `evil-keypad-activation-states`."
   (or (and (bound-and-true-p which-key-idle-delay) which-key-idle-delay) 0.4))
 
 (defun evil-keypad--schedule-display (&optional binding)
-  "Cancel any existing display timer and schedule `evil-keypad--display-bindings-function'.
+  "Schedule the display of available bindings cancelling any existing timer.
 If BINDING is non‑nil, pass it to that function; otherwise call with no args."
   (evil-keypad--cancel-display-timer)
   (setq evil-keypad--display-timer
@@ -255,28 +270,22 @@ If BINDING is non‑nil, pass it to that function; otherwise call with no args."
                              evil-keypad--display-bindings-function
                              binding)))
 
-(defvar evil-keypad--initial-display-map nil
-  "Keymap pre-calculated for initial which-key display when keypad starts.")
-
 (defun evil-keypad--make-initial-display-map ()
   "Create and return a keymap for initial which-key display."
-  (let ((map (make-sparse-keymap "Evil Keypad Initial Actions")))
-    (define-key map (vector evil-keypad-C-x-trigger) "C-x-prefix")
-    (define-key map (vector evil-keypad-C-c-trigger) "C-c-prefix")
-    (define-key map (vector evil-keypad-C-h-trigger) "C-h-prefix")
-    (define-key map (vector evil-keypad-M-trigger)   "M-trigger")
-    (define-key map (vector evil-keypad-C-M-trigger) "C-M-trigger")
-    (define-key map (vector evil-keypad-universal-argument-trigger) "universal-argument")
-    (define-key map (vector evil-keypad-negative-argument-trigger) "negative-argument")
-    (define-key map (kbd "ESC") #'evil-keypad-quit)
+  (let ((map (copy-keymap mode-specific-map)))
+    (define-key map (vector evil-keypad-C-x-trigger) "keypad/C-x-prefix")
+    (define-key map (vector evil-keypad-C-c-trigger) "keypad/C-c-prefix")
+    (define-key map (vector evil-keypad-C-h-trigger) "keypad/C-h-prefix")
+    (define-key map (vector evil-keypad-M-trigger)   "keypad/M-trigger")
+    (define-key map (vector evil-keypad-C-M-trigger) "keypad/C-M-trigger")
+    (define-key map (vector evil-keypad-universal-argument-trigger) "keypad/universal-arg")
+    (define-key map (vector evil-keypad-negative-argument-trigger) "keypad/negative-arg")
+    (define-key map evil-keypad-quit-key #'evil-keypad-quit)
     map))
 
-;; Initialize it once when the file is loaded
-(setq evil-keypad--initial-display-map (evil-keypad--make-initial-display-map))
-
 (defun evil-keypad--trigger-which-key-display (&optional target-keymap)
   "Show relevant bindings using which-key.
-If TARGET-KEYMAP is non-nil, display that Emacs keymap. Otherwise, show
+If TARGET-KEYMAP is non-nil, display that Emacs keymap.  Otherwise, show
 the initial evil-keypad trigger keys."
   (evil-keypad--cancel-display-timer)
   (condition-case err
@@ -285,7 +294,7 @@ the initial evil-keypad trigger keys."
         (if (null evil-keypad--keys)
             (if evil-keypad--session-active-prefix-arg
                 (funcall evil-keypad--clear-display-function)
-              (which-key--create-buffer-and-show nil evil-keypad--initial-display-map nil nil))
+              (which-key--create-buffer-and-show nil (evil-keypad--make-initial-display-map) nil "C-c"))
           (funcall evil-keypad--clear-display-function)))
     (error (message "Error showing which-key: %S" err))))
 
@@ -306,9 +315,15 @@ the initial evil-keypad trigger keys."
       (setq which-key-show-prefix evil-keypad--original-which-key-show-prefix)
       (setq evil-keypad--original-which-key-show-prefix nil))))
 
-(with-eval-after-load 'which-key
-  (add-hook 'which-key-mode-hook #'evil-keypad--which-key-integration-setup)
-  (evil-keypad--which-key-integration-setup))
+;; Add which-key hook if which-key is available
+(defun evil-keypad--maybe-setup-which-key-integration ()
+  "Set up which-key integration if which-key is loaded."
+  (when (featurep 'which-key)
+    (add-hook 'which-key-mode-hook #'evil-keypad--which-key-integration-setup)
+    (evil-keypad--which-key-integration-setup)))
+
+;; Initialize which-key integration if already loaded
+(evil-keypad--maybe-setup-which-key-integration)
 
 ;;----------------------------------------
 ;; Core Logic
@@ -317,20 +332,19 @@ the initial evil-keypad trigger keys."
 (defun evil-keypad--keymap-has-ctrl-meta-bindings-p (keymap)
   "Return t if KEYMAP contains any C-M- modified single key bindings."
   (when (keymapp keymap)
-    (let ((found nil))
+    (catch 'found
       (map-keymap
        (lambda (key _binding)
          (unless (vectorp key) ; Process single events
            (let ((mods (event-modifiers key)))
              (when (and (memq 'control mods) (memq 'meta mods))
-               (setq found t)
-               (cl-return-from evil-keypad--keymap-has-ctrl-meta-bindings-p t)))))
+               (throw 'found t)))))
        keymap)
-      found)))
+      nil)))
 
 (defun evil-keypad--context-allows-modifier-type-p (modifier-type)
   "Check if the current keypad context allows for PENDING-MODIFIER-TYPE.
-MODIFIER-TYPE is 'meta or 'control-meta."
+MODIFIER-TYPE is \\='meta or \\='control-meta."
   (if (null evil-keypad--keys) ; If at the very start of keypad input
       t ; Always allow m/g to trigger initially
     (let* ((seq-str (evil-keypad--format-sequence evil-keypad--keys))
@@ -347,11 +361,13 @@ MODIFIER-TYPE is 'meta or 'control-meta."
   "Execute COMMAND, applying the active prefix argument."
   (condition-case err
       (let ((current-prefix-arg evil-keypad--session-active-prefix-arg))
+        (setq this-command command)
         (call-interactively command))
     (error (message "Error executing %s: %s" command err))))
 
 (defun evil-keypad--try-execute ()
-  "Check current sequence, execute/fallback, or update echo/which-key. Returns t to exit."
+  "Check current sequence, execute/fallback, or update echo/which-key.
+Returns t to exit."
   (if evil-keypad--pending-modifier
       (progn (evil-keypad--display-pending-state) nil)
     (if (null evil-keypad--keys)
@@ -383,17 +399,19 @@ MODIFIER-TYPE is 'meta or 'control-meta."
 (defun evil-keypad-quit ()
   "Interactive command to quit keypad."
   (interactive)
+  (setq this-command last-command)
   (evil-keypad--quit) t)
 
 ;;;###autoload
 (defun evil-keypad-undo ()
   "Interactive command to undo last keypad input."
   (interactive)
+  (setq this-command last-command)
   (evil-keypad--cancel-display-timer-and-clear)
   (cond
    (evil-keypad--pending-modifier
     (setq evil-keypad--pending-modifier nil))
-   ((not (null evil-keypad--keys))
+   (evil-keypad--keys
     (pop evil-keypad--keys))
    ((not (equal evil-keypad--session-active-prefix-arg evil-keypad--session-initial-prefix-arg))
     (setq evil-keypad--session-active-prefix-arg evil-keypad--session-initial-prefix-arg))
@@ -406,18 +424,32 @@ MODIFIER-TYPE is 'meta or 'control-meta."
   (evil-keypad--try-execute)
   nil)
 
-(defvar evil-keypad-state-keymap (make-sparse-keymap) "Keymap for keypad internal commands.")
-(define-key evil-keypad-state-keymap (kbd "<escape>") #'evil-keypad-quit)
-(define-key evil-keypad-state-keymap (kbd "ESC") #'evil-keypad-quit)
-(define-key evil-keypad-state-keymap (kbd "<backspace>") #'evil-keypad-undo)
-(define-key evil-keypad-state-keymap (kbd "DEL") #'evil-keypad-undo)
+(defun evil-keypad--make-state-keymap ()
+  "Create and return the keypad state keymap."
+  (let ((map (make-sparse-keymap)))
+    (define-key map evil-keypad-quit-key #'evil-keypad-quit)
+
+    (define-key map (kbd "<backspace>") #'evil-keypad-undo)
+    (define-key map (kbd "DEL") #'evil-keypad-undo)
+    map))
+
+(defvar evil-keypad-state-keymap (evil-keypad--make-state-keymap)
+  "Keymap for keypad internal commands.")
 
 (defun evil-keypad--echo (format-string &rest args)
-  "Display a message in the echo area."
+  "Display a message in the echo area with a \"Keypad:\" prefix.
+FORMAT-STRING is the format string passed to `format`.
+ARGS are the arguments for the format string."
   (message "Keypad: %s" (apply #'format format-string args)))
 
+(defun evil-keypad--get-current-keymap ()
+  "Get the keymap for the current key sequence."
+  (let* ((seq-str (evil-keypad--format-sequence evil-keypad--keys))
+         (seq-vec (if (string-empty-p seq-str) nil (kbd seq-str))))
+    (if seq-vec (key-binding seq-vec t) (current-global-map))))
+
 (defun evil-keypad--display-pending-state ()
-  "Display the current prefix arg, sequence, and pending modifier. Returns nil."
+  "Display the current prefix arg, sequence, and pending modifier.  Returns nil."
   (let ((prefix-str (evil-keypad--format-prefix-arg evil-keypad--session-active-prefix-arg))
         (seq-str (if evil-keypad--keys (evil-keypad--format-sequence evil-keypad--keys) ""))
         (pending-mod-str (cl-case evil-keypad--pending-modifier
@@ -434,7 +466,9 @@ MODIFIER-TYPE is 'meta or 'control-meta."
 
 (defun evil-keypad--handle-prefix-binding (binding seq-str)
   "Handle a key sequence that maps to a prefix (keymap).
-Displays prefix in echo area and schedules which-key. Returns nil."
+Displays prefix in echo area and schedules which-key display.  Returns nil.
+BINDING is the keymap the key sequence maps to.
+SEQ-STR is the formatted key sequence string."
   (let ((prefix-str (evil-keypad--format-prefix-arg evil-keypad--session-active-prefix-arg)))
     (if (string-empty-p prefix-str)
         (evil-keypad--echo "%s-" seq-str)
@@ -442,12 +476,25 @@ Displays prefix in echo area and schedules which-key. Returns nil."
   (evil-keypad--schedule-display binding)
   nil)
 
-(defun evil-keypad--handle-command-binding (binding seq-str)
-  "Handle a key sequence that maps to a command. Executes and returns t."
+(defun evil-keypad--handle-command-binding (binding _seq-str)
+  "Handle a key sequence that maps to a command.  Executes and returns t.
+BINDING is the command to execute with the current prefix argument."
   (evil-keypad--cancel-display-timer-and-clear)
   (evil-keypad--execute binding)
   t)
 
+(defun evil-keypad--handle-help-request (keymap)
+  "Handle a help request for the given KEYMAP."
+  (if (and evil-keypad-prefix-help-command
+           (fboundp evil-keypad-prefix-help-command))
+      (progn
+        (evil-keypad--cancel-display-timer-and-clear)
+        (funcall evil-keypad-prefix-help-command keymap)
+        (evil-keypad--quit)
+        t)
+    (ding)
+    nil))
+
 (defun evil-keypad--handle-unbound-sequence (original-seq-str)
   "Handle an unbound ORIGINAL-SEQ-STR, attempting fallback.
 Returns t to exit, nil to continue (if fallback leads to new prefix)."
@@ -480,7 +527,7 @@ Returns t to exit, nil to continue (if fallback leads to new prefix)."
       t))))
 
 (defun evil-keypad--set-new-pending-modifier (event)
-  "Handle EVENT when it's a new modifier trigger (m, g, SPC). Returns nil."
+  "Handle EVENT when it's a new modifier trigger (m, g, SPC).  Returns nil."
   (cond
    ((eq event evil-keypad-M-trigger)
     (setq evil-keypad--pending-modifier 'meta
@@ -512,6 +559,8 @@ Returns result of `evil-keypad--try-execute` (t to exit, nil to continue)."
               (setq add-implicit-C-c-prefix-p t)
               (setq evil-keypad--control-inducing-sequence-p nil) 'literal)))
            (evil-keypad--control-inducing-sequence-p 'control)
+           ((and (characterp event) (< event 32)) ; Check for control character
+            'literal)
            (t 'literal))))
     (setq evil-keypad--keys
           (if add-implicit-C-c-prefix-p
@@ -522,7 +571,7 @@ Returns result of `evil-keypad--try-execute` (t to exit, nil to continue)."
   (evil-keypad--try-execute))
 
 (defun evil-keypad--handle-universal-argument-trigger ()
-  "Handle the universal argument trigger 'u'. Returns nil."
+  "Handle the universal argument trigger \\='u\\='.  Returns nil."
   (setq evil-keypad--session-active-prefix-arg
         (let ((arg evil-keypad--session-active-prefix-arg))
           (cond
@@ -534,7 +583,7 @@ Returns result of `evil-keypad--try-execute` (t to exit, nil to continue)."
   nil)
 
 (defun evil-keypad--handle-negative-argument-trigger ()
-  "Handle the negative argument trigger '-'. Returns nil."
+  "Handle the negative argument trigger '-'.  Returns nil."
   (setq evil-keypad--session-active-prefix-arg
         (let ((arg evil-keypad--session-active-prefix-arg))
           (cond
@@ -546,7 +595,8 @@ Returns result of `evil-keypad--try-execute` (t to exit, nil to continue)."
   nil)
 
 (defun evil-keypad--handle-digit-argument-trigger (digit-char)
-  "Handle a digit char for prefix argument. Returns nil."
+  "Handle a digit character for building a numeric prefix argument.  Returns nil.
+DIGIT-CHAR is the digit character (0-9) that was pressed."
   (let ((digit-val (string-to-number (string digit-char))))
     (setq evil-keypad--session-active-prefix-arg
           (let ((arg evil-keypad--session-active-prefix-arg))
@@ -562,7 +612,8 @@ Returns result of `evil-keypad--try-execute` (t to exit, nil to continue)."
   nil)
 
 (defun evil-keypad--maybe-set-pending-modifier (event mod-from-pending)
-  "Conditionally set `evil-keypad--pending-modifier' based on EVENT and MOD-FROM-PENDING."
+  "Set pending modifier based on EVENT and MOD-FROM-PENDING.
+EVENT is the key event pressed.  MOD-FROM-PENDING is the pending modifier."
   (let ((key-is-m-trigger (eq event evil-keypad-M-trigger))
         (key-is-cm-trigger (eq event evil-keypad-C-M-trigger))
         (key-is-literal-trigger (eq event evil-keypad-literal-trigger)))
@@ -577,13 +628,18 @@ Returns result of `evil-keypad--try-execute` (t to exit, nil to continue)."
       (evil-keypad--process-resolved-key event mod-from-pending)))))
 
 (defun evil-keypad--handle-input (event)
-  "Handle a single EVENT. Returns t if loop should exit, nil otherwise."
+  "Handle a single EVENT.  Returns t if loop should exit, nil otherwise."
   (evil-keypad--cancel-display-timer)
   (let ((cmd (lookup-key evil-keypad-state-keymap (vector event))))
     (if cmd
         (call-interactively cmd)
       (let ((is-initial-phase (and (null evil-keypad--keys) (null evil-keypad--pending-modifier))))
         (cond
+         ((and (eq event help-char)
+               (not (lookup-key (evil-keypad--get-current-keymap) (vector event) t)))
+          (if (keymapp (evil-keypad--get-current-keymap))
+              (evil-keypad--handle-help-request (evil-keypad--get-current-keymap))
+            (progn (ding) nil)))
          ((and is-initial-phase
                (eq event evil-keypad-universal-argument-trigger))
           (evil-keypad--handle-universal-argument-trigger)
@@ -606,7 +662,8 @@ Returns result of `evil-keypad--try-execute` (t to exit, nil to continue)."
   "Start the Evil Keypad transient mode."
   (interactive)
   (evil-keypad--cancel-display-timer-and-clear)
-  (setq evil-keypad--keys nil
+  (setq this-command last-command
+        evil-keypad--keys nil
         evil-keypad--pending-modifier nil
         evil-keypad--session-initial-prefix-arg current-prefix-arg
         evil-keypad--session-active-prefix-arg evil-keypad--session-initial-prefix-arg
